@@ -2,4 +2,5 @@
 library(testthat)
 library(seqminer)
 ## test code are under inst/tests
-test_package("seqminer", reporter="tap")
+## test_package("seqminer", reporter="tap")
+test_package("seqminer")
